@@ -1,10 +1,12 @@
 """partition.py implements logic for partitioning plain text documents into sections."""
 import sys
 
+from typing import List, Optional
+
 if sys.version_info < (3, 8):
-    from typing_extensions import Final, List, Optional
+    from typing_extensions import Final
 else:
-    from typing import Final, List, Optional
+    from typing import Final
 
 from unstructured.cleaners.core import remove_punctuation
 from unstructured.nlp.patterns import UNICODE_BULLETS_RE
